Skip to content

Configuration

lime-files

The LibreMesh configuration is mainly done by a set of /etc/config/lime-<level> files. These files can be managed via the OpenWrt UCI or manually edited using vim.
To modify them via the LuCI web interface install luci-app-filemanager.

The options contained in these files are merged and overwritten from the lowest to the highest priority:

/etc/config/
├─ lime-defaults - DO NOT EDIT, default configuration
├─ lime-community - community configuration
├─ lime-<MAC> - node configuration, device specific
├─ lime-node - node configuration
└─ lime-autogen - DO NOT EDIT, autogenerated configuration

Interface specific options

Interface specific options have to be included in lime-node or lime-<MAC>. If in lime-community they'll cause unpredictable behaviour.

Parametrizable options

Inside lime-files the options marked with Parametrizable with %Mn, %Nn, %H, can include the templates:

  • %Mn: replaced by the n'th byte of the primary_interface MAC
  • %Nn: replaced by the n'th (n = 1..5) network-identifier byte, calculated from the hash of the ap_ssid. All the nodes that form a mesh cloud (share the same ap_ssid) will produce the same value
  • %H: replaced by the hostname

lime-config

The command lime-config configures LibreMesh on top of OpenWrt.
Refers to the page lime-config for the details.